DecisionState

Struct DecisionState 

pub struct DecisionState {
    pub id: DecisionId,
    /* private fields */
}

Fields

id: DecisionId

Implementations

Source

impl DecisionState

pub fn new(id: DecisionId, owner: String) -> Self

pub fn answer( &mut self, owner: &str, ciphertext: Ciphertext, digest: SecretDigest, ) -> Result<()>

pub fn release(&mut self) -> Result<()>

pub fn add_released(&mut self, value: String) -> Result<()>

Add the decryption result.

So that it can be read inside the game handler.

pub fn add_secret(&mut self, owner: &str, secret: SecretKey) -> Result<()>

Add the shared secret and update the status.

The secret will be used to decrypt the answer.

pub fn get_secret(&self) -> Result<&SecretKey>

pub fn is_answered(&self) -> bool

pub fn is_prompted(&self) -> bool

pub fn is_revealed(&self) -> bool

pub fn is_revealing(&self) -> bool

pub fn get_answer(&self) -> Option<&Answer>

pub fn get_revealed(&self) -> Option<&String>

pub fn get_owner(&self) -> &str