RandomState

Struct RandomState 

pub struct RandomState {
    pub id: RandomId,
    pub size: usize,
    pub owners: Vec<String>,
    pub options: Vec<String>,
    pub status: RandomStatus,
    pub masks: Vec<Mask>,
    pub ciphertexts: Vec<LockedCiphertext>,
    pub secret_shares: Vec<Share>,
    pub revealed: HashMap<usize, String>,
}
RandomState represents the public information for a single randomness.

Fields

id: RandomIdsize: usizeowners: Vec<String>options: Vec<String>status: RandomStatusmasks: Vec<Mask>ciphertexts: Vec<LockedCiphertext>secret_shares: Vec<Share>revealed: HashMap<usize, String>

Implementations

Source

impl RandomState

pub fn is_fully_masked(&self) -> bool

pub fn is_fully_locked(&self) -> bool

pub fn is_shared(&self) -> bool

pub fn is_ready(&self) -> bool

pub fn get_ciphertext(&self, index: usize) -> Option<&LockedCiphertext>

pub fn get_ciphertext_unchecked(&self, index: usize) -> &LockedCiphertext

pub fn try_new( id: RandomId, spec: RandomSpec, owners: &[String], ) -> Result<Self>

pub fn mask<S: AsRef<str>>( &mut self, addr: S, ciphertexts: Vec<Ciphertext>, ) -> Result<()>

pub fn lock<S>( &mut self, addr: S, ciphertexts_and_digests: Vec<(Ciphertext, SecretDigest)>, ) -> Result<()>
where S: Into<String> + AsRef<str> + Clone,

pub fn assign<S>(&mut self, addr: S, indexes: Vec<usize>) -> Result<()>
where S: ToOwned<Owned = String>,

pub fn reveal(&mut self, indexes: Vec<usize>) -> Result<()>

pub fn list_required_secrets_by_from_addr( &self, from_addr: &str, ) -> Vec<SecretIdent>

pub fn list_revealed_secrets(&self) -> Result<HashMap<usize, Vec<Ciphertext>>>

pub fn list_assigned_ciphertexts( &self, addr: &str, ) -> HashMap<usize, Ciphertext>

List all ciphertexts assigned to a specific address. Return a mapping from item index to ciphertext.

pub fn list_revealed_ciphertexts(&self) -> HashMap<usize, Ciphertext>

pub fn list_shared_secrets( &self, to_addr: &str, ) -> Result<HashMap<usize, Vec<SecretKey>>>

List shared secrets by receiver address. Return a mapping from item index to list of secrets(each is in HEX format). Return [Error::SecretsNotReady] in case of any missing secret.

pub fn add_revealed(&mut self, revealed: HashMap<usize, String>) -> Result<()>

pub fn get_revealed(&self) -> &HashMap<usize, String>

pub fn add_secret( &mut self, from_addr: String, to_addr: Option<String>, index: usize, secret: SecretKey, ) -> Result<()>

pub fn list_operating_addrs(&self) -> Vec<String>

Return addresses those haven’t submitted operation

pub fn update_status(&mut self)

Update randomness status