EntryType

Enum EntryType 

pub enum EntryType {
    Cash {
        min_deposit: u64,
        max_deposit: u64,
    },
    Ticket {
        slot_id: u8,
        amount: u64,
    },
    Gating {
        collection: String,
    },
}

Variants



Cash

A player can join the game by sending assets to game account directly

Fields

min_deposit: u64
max_deposit: u64


Ticket

A player can join the game by pay a ticket.

Fields

slot_id: u8
amount: u64


Gating

A player can join the game by showing a gate NFT

Fields

collection: String